
* Windows

Anaconda 2.7 (full install)

from cmd:
 - conda install pandas numexpr seaborn traits pyface envisage pyqt
 - pip install FlowCytometryTools
 - clone the repo
 - python setup.py develop
 - python run.py
